@@ -1,21 +1,11 @@
-use crate::{
-  arguments::Arguments,
-  error::{self, Result},
-  stderr::Stderr,
-};
-use snafu::ResultExt;
-use std::{env, ffi::OsString, path::PathBuf};
-use structopt::StructOpt;
-
-#[cfg(test)]
-use tempfile::TempDir;
+use crate::common::*;
 
 pub(crate) struct Environment {
   pub(crate) arguments: Vec<OsString>,
   pub(crate) working_directory: PathBuf,
   pub(crate) stderr: Stderr,
   #[cfg(test)]
-  pub(crate) working_directory_tempdir: TempDir,
+  _working_directory_tempdir: TempDir,
 }
 
 impl Environment {
@@ -25,7 +15,7 @@ impl Environment {
       stderr: Stderr::production(),
       working_directory: env::current_dir().context(error::CurrentDir)?,
       #[cfg(test)]
-      working_directory_tempdir: TempDir::new().unwrap(),
+      _working_directory_tempdir: TempDir::new().unwrap(),
     })
   }
 
@@ -40,12 +30,12 @@ impl Environment {
       arguments: vec![
         "agora".into(),
         "--address=localhost".into(),
-        "--port=0".into(),
+        "--http-port=0".into(),
         "--directory=www".into(),
       ],
       stderr: Stderr::test(),
       working_directory: tempdir.path().to_owned(),
-      working_directory_tempdir: tempdir,
+      _working_directory_tempdir: tempdir,
     }
   }
 
