@@ -1,7 +1,7 @@
 use crate::common::*;
 use maud::{html, DOCTYPE};
 
-pub(crate) fn wrap_body(body: Markup) -> Response<Body> {
+pub(crate) fn wrap_body(title_slug: &str, body: Markup) -> Response<Body> {
   let html = html! {
     (DOCTYPE)
     html lang="en" {
@@ -9,7 +9,7 @@ pub(crate) fn wrap_body(body: Markup) -> Response<Body> {
         meta charset="utf-8";
         meta name="viewport" content="width=device-width, initial-scale=1";
         title {
-          "agora"
+          (format!("{} · Agora", title_slug))
         }
         link rel="stylesheet" href="/static/index.css";
         script type="module" src="/static/index.js" {}
