@@ -1,11 +1,6 @@
-use crate::{
-  environment::Environment,
-  error::{self, Error, Result},
-};
+use crate::common::*;
 use mime_guess::MimeGuess;
-use percent_encoding::percent_decode_str;
-use std::path::{Component, Path, PathBuf};
-use std::{borrow::Cow, fmt::Debug};
+use std::path::Component;
 
 #[derive(Debug, Clone, PartialEq)]
 pub(crate) struct InputPath {
@@ -16,8 +11,8 @@ pub(crate) struct InputPath {
 impl InputPath {
   pub(crate) fn new(environment: &Environment, display_path: &Path) -> Self {
     Self {
-      full_path: Self::canonicalize(&environment.working_directory.join(display_path)),
-      display_path: Self::canonicalize(display_path),
+      full_path: environment.working_directory.join(display_path).lexiclean(),
+      display_path: display_path.lexiclean(),
     }
   }
 
@@ -29,8 +24,8 @@ impl InputPath {
       )));
     }
     Ok(Self {
-      full_path: Self::canonicalize(&self.full_path.join(path)),
-      display_path: Self::canonicalize(&self.display_path.join(path)),
+      full_path: self.full_path.join(path).lexiclean(),
+      display_path: self.display_path.join(path).lexiclean(),
     })
   }
 
@@ -47,31 +42,18 @@ impl InputPath {
   }
 
   fn join_file_path_option(&self, uri_path: &str) -> Option<Result<Self>> {
-    let relative_path = Self::percent_decode(uri_path)?;
-
-    for component in Path::new(&relative_path).components() {
+    for component in Path::new(&uri_path).components() {
       match component {
         Component::Normal(_) => {}
         _ => return None,
       }
     }
 
-    if relative_path.contains("//") {
+    if uri_path.contains("//") {
       return None;
     }
 
-    Some(self.join_relative(Path::new(&relative_path)))
-  }
-
-  fn canonicalize(path: &Path) -> PathBuf {
-    path.components().collect()
-  }
-
-  fn percent_decode(path: &str) -> Option<String> {
-    percent_decode_str(path)
-      .decode_utf8()
-      .ok()
-      .map(Cow::into_owned)
+    Some(self.join_relative(Path::new(&uri_path)))
   }
 
   pub(crate) fn display_path(&self) -> &Path {
